Author: John J. Lee <jjl@pobox.com>
Keywords: Python,HTML,HTTP,browser,stateful,web,client,client-side,mechanize,cookie,form,META,HTTP-EQUIV,Refresh,ClientForm,ClientCookie,pullparser,WWW::Mechanize
Date: 2010-04-18

# mechanize — Development

## git repository

The git repository is here. To check it out:

`git clone git://github.com/jjlee/mechanize.git`

There is also another repository, which is only useful for making mechanize releases:

`git clone git://github.com/jjlee/mechanize-build-tools.git`

## Old repository

The old SVN repository may be useful for viewing ClientForm history. ClientForm used to be a dependency of mechanize, but has been merged into mechanize as of release 0.2.0; the history wasn’t imported. To check out:

`svn co http://codespeak.net/svn/wwwsearch/`

## Bug tracker

The bug tracker is here on github. It’s equally acceptable to file bugs on the tracker or post about them to the mailing list. Feel free to send patches too!

## Mailing list

There is a mailing list.

I prefer questions and comments to be sent to the mailing list rather than direct to me.

John J. Lee, April 2010.